@@ -28,7 +28,7 @@ void Audio::createWav(QString filename)
     QString audio = filename;
     audio.chop(3);
     audio.append("wav");
-    audioFile = new QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) + "/AudioWiki/"+ audio);
+    audioFile = new QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) + audio);
     if (!audioFile->open(QIODevice::ReadWrite))
         qDebug()<<"cannot write to file";
     else
